Map

Struct Map 

pub struct Map<K, V> { /* private fields */ }
Map is a data structure with a HashMap-like API but based on a Vec.

It’s primarily useful when you care about constant factors or prefer determinism to speed. Please refer to the docs for HashMap for details and examples of the Map API.

Example

let mut map = map_vec::Map::new();
map.insert("hello".to_string(), "world".to_string());
map.entry("hello".to_string()).and_modify(|mut v| v.push_str("!"));
assert_eq!(map.get("hello").map(String::as_str), Some("world!"))

Implementations



impl<K, V> Map<K, V>
where K: Eq,

pub fn new() -> Map<K, V>

pub fn with_capacity(capacity: usize) -> Map<K, V>

pub fn capacity(&self) -> usize

pub fn clear(&mut self)

pub fn contains_key<Q>(&self, key: &Q) -> bool
where K: Borrow<Q>, Q: Eq + ?Sized,

pub fn drain(&mut self) -> Drain<'_, (K, V)>

pub fn entry(&mut self, key: K) -> Entry<'_, K, V>

pub fn get<Q>(&self, key: &Q) -> Option<&V>
where K: Borrow<Q>, Q: Eq + ?Sized,

pub fn get_key_value<Q>(&self, key: &Q) -> Option<(&K, &V)>
where K: Borrow<Q>, Q: Eq + ?Sized,

pub fn get_mut<Q>(&mut self, key: &Q) -> Option<&mut V>
where K: Borrow<Q>, Q: Eq + ?Sized,

pub fn insert(&mut self, key: K, value: V) -> Option<V>

pub fn is_empty(&self) -> bool

pub fn iter(&self) -> Iter<'_, K, V>

pub fn iter_mut(&mut self) -> IterMut<'_, K, V>

pub fn keys(&self) -> Keys<'_, K, V>

pub fn len(&self) -> usize

pub fn remove<Q>(&mut self, key: &Q) -> Option<V>
where K: Borrow<Q>, Q: Eq + ?Sized,

pub fn remove_entry<Q>(&mut self, key: &Q) -> Option<(K, V)>
where K: Borrow<Q>, Q: Eq + ?Sized,

pub fn reserve(&mut self, additional: usize)

pub fn retain<F>(&mut self, f: F)
where F: FnMut(&K, &mut V) -> bool,

pub fn shrink_to_fit(&mut self)

pub fn values(&self) -> Values<'_, K, V>

pub fn values_mut(&mut self) -> ValuesMut<'_, K, V>

pub fn shrink_to(&mut self, min_capacity: usize)

pub fn try_reserve(&mut self, additional: usize) -> Result<(), TryReserveError>